### Name: DSA
### Title: Data-Adaptive Estimation with Cross-Validation
### Aliases: DSA
### Keywords: models

### ** Examples

  require(DSA)
  set.DSA.message.level(-1) # no printing. 

  ## an example using the state census data. (ols)  
  data(state)
  W <- state.x77[,c(1,2,3,4,6,7,8)]
  Y <- as.matrix(W[,1]*state.x77[,5]/100)
  colnames(W) <- c("pop", "inc", "illiteracy", "lifeexp", "hsgrad",
                   "frost", "area")
  colnames(Y) <- c("murders")
  res <- DSA(W, Y, binind = 0, maxsize = 5, maxsumofpow = 2, maxorderint = 2)
  res$model.selected

  ## an example using weights (ols).
  ddir <- paste(system.file(package = "DSA"), "/", "data", "/", sep = "")
  x <- as.matrix(read.table(paste(ddir, "smalllymphRoX.txt", sep = ""),nrow=240))
  dimnames(x) <- list(NULL,dimnames(x)[[2]])
  y <- as.matrix(read.table(paste(ddir, "logT1lymph.txt", sep = "")))
  dimnames(y) <- list(NULL,"Y")
  SplitBn <- as.matrix(read.table(paste(ddir, "bnVectors_lymph_v5", sep = "")))
  WeightsV <- as.matrix(read.table(paste(ddir, "lymphWeights_111505", sep = "")))
  
  res <- DSA(Xlearn=x, Ylearn=y, binind=0, maxsize=5, maxorderint=2, maxsumofpow=2,
             nfolds=5, CENSOR=1, weights=WeightsV, vsplits=SplitBn)
  res$model.selected

  ## an example using simulated data (logistic).
  n <- 1000
  W <- cbind(rnorm(n), rnorm(n) < 1, rnorm(n) < 2, rnorm(n, 2, 4), runif(n),
             rcauchy(n), rlogis(n) < .1, rnorm(n) < .1, rnorm(n, 120, 10),
             rnorm(n, 66, 2))

  Y <- 22 + .5*W[,1] + .02*W[,1]^2 + .01*W[,1]*W[,2] + 2*W[,3] + .7*W[,4]^2 
  Y <- as.matrix(as.integer(Y - mean(Y))/sd(Y))

  Y <- as.matrix(as.integer(Y < rlogis(1))) # apply(Y, 1, function(x) { rbinom(1,1,exp(x)/(1+exp(x))) }))

  colnames(W) <- paste("V", 1:ncol(W), sep = "")
  colnames(Y) <- "Y"
  
  res <- DSA(W, Y, binind = 1, maxsize = 8, maxorderint = 2, maxsumofpow = 3)  




